@@ -55,9 +55,10 @@ sub scan
 {
 	my ($self, $path) = @_;
 
-	if(abs_path($path) ne $path) {
-		return File::VirusScan::Result->error("Path $path is not absolute");
-	}
+        my $abs = abs_path($path);
+        if ($abs && $abs ne $path) {
+                $path = $abs;
+        }
 
 	my $sock = eval { $self->_get_socket };
 	if($@) {
